/*
 * miscdev.c
 *
 * Copyright 2003, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * ¾ΥǥХɥ饤С
 */


#include"types.h"
#include"device.h"


/************************************************************************************************
 *
 * Null device class
 *
 * ⤷ʤ
 *
 ************************************************************************************************/

static int open()
{
	return 0;
}


static int read(void* buf,size_t size,size_t begin)
{
	return 0;
}


static int write(void* buf,size_t size,size_t begin)
{
	return 0;
}


static int ioctl(int prm_num,int cmd,...)
{
	return 0;
}


static DEV_INFO devInfo={
	"null",0,0,0,open,read,write,ioctl,
};


int registNullDev()
{
	return regist_device(&devInfo);
}
